# Security Policy

## Reporting a Vulnerability
(Following https://github.com/tensorflow/tensorflow/blob/master/SECURITY.md)

Please email reports about any security related issues you find to info@lfai.foundation. This mail is delivered to a small team maintaining the Trusted-AI projects. Your email will be acknowledged within a few business day, and you'll receive a more detailed response to your email within 7 days indicating the next steps in handling your report.

Please use a descriptive subject line for your report email. After the initial reply to your report, the team will endeavor to keep you informed of the progress being made towards a fix and announcement.

In addition, please include the following information along with your report:

Your name and affiliation (if any).
A description of the technical details of the vulnerabilities. It is very important to let us know how we can reproduce your findings.
An explanation who can exploit this vulnerability, and what they gain when doing so -- write an attack scenario. This will help us evaluate your report quickly, especially if the issue is complex.
Whether this vulnerability public or known to third parties. If it is, please provide details.
If you believe that an existing (public) issue is security-related, please send an email to info@lfai.foundation. The email should include the issue ID and a short description of why it should be handled according to this security policy.

We apply the following disclosure process:

When a report is received, we confirm the issue and determine its severity.
If we know of specific third-party services or software based on ART that require mitigation before publication, those projects will be notified.
An advisory is prepared (but not published) which details the problem and steps for mitigation.
The vulnerability is fixed and potential workarounds are identified.
Wherever possible, the fix is also prepared for the branches corresponding to all releases of ART at most one year old. We will attempt to commit these fixes as soon as possible, and as close together as possible.

Patch releases are published for all fixed released versions and the advisory is published.

Note that each version of ART is supported for only 1 year after the release.
